package com.ghy.order.mapper;

import java.util.List;
import com.ghy.order.domain.OrderWarnRecord;

/**
 * 订单急报记录Mapper接口
 *
 * @author clunt
 * @date 2024-02-18
 */
public interface OrderWarnRecordMapper
{
    /**
     * 查询订单急报记录
     *
     * @param id 订单急报记录主键
     * @return 订单急报记录
     */
    public OrderWarnRecord selectOrderWarnRecordById(Long id);

    /**
     * 查询订单急报记录列表
     *
     * @param orderWarnRecord 订单急报记录
     * @return 订单急报记录集合
     */
    public List<OrderWarnRecord> selectOrderWarnRecordList(OrderWarnRecord orderWarnRecord);

    /**
     * 新增订单急报记录
     *
     * @param orderWarnRecord 订单急报记录
     * @return 结果
     */
    public int insertOrderWarnRecord(OrderWarnRecord orderWarnRecord);

    /**
     * 修改订单急报记录
     *
     * @param orderWarnRecord 订单急报记录
     * @return 结果
     */
    public int updateOrderWarnRecord(OrderWarnRecord orderWarnRecord);

    /**
     * 删除订单急报记录
     *
     * @param id 订单急报记录主键
     * @return 结果
     */
    public int deleteOrderWarnRecordById(Long id);

    /**
     * 批量删除订单急报记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderWarnRecordByIds(String[] ids);
}